@@ -12,7 +12,7 @@ use App::TimelogTxt::Day;
 use App::TimelogTxt::File;
 use App::TimelogTxt::Event;
 
-our $VERSION = '0.12';
+our $VERSION = '0.20';
 
 # Initial configuration information.
 my %config = (
@@ -106,6 +106,13 @@ if argument supplied.',
         help     => q{Display the hours worked for each of the appropriate days
 and projects.},
     },
+    'curr' => {
+        code     => \&current_event,
+        clue     => 'curr',
+        abstract => 'Display current event.',
+        help     => q{Display the current event (if any) and the time since the
+event started.},
+    },
 );
 
 # Sub class of App::CmdDispatch that initializes configuration information
@@ -118,11 +125,16 @@ and projects.},
     {
         my $self = App::CmdDispatch::new( @_ );
         $self->init();
+        $self->{_timelog_out_fh} = \*STDOUT;
         return $self;
     }
 
     sub _logfile   { return $_[0]->get_config()->{'logfile'}; }
     sub _stackfile { return $_[0]->get_config()->{'stackfile'}; }
+    sub _out_fh    { return $_[0]->{_timelog_out_fh}; }
+
+    # Support injection of an output filehandle for testing.
+    sub _set_out_fh { return $_[0]->{_timelog_out_fh} = $_[1]; }
 
     sub init
     {
@@ -253,7 +265,7 @@ sub daily_report
 
     foreach my $summary ( @{$summaries} )
     {
-        $summary->print_day_detail( \*STDOUT );
+        $summary->print_day_detail( $app->_out_fh );
     }
     return;
 }
@@ -266,7 +278,7 @@ sub daily_summary
 
     foreach my $summary ( @{$summaries} )
     {
-        $summary->print_day_summary( \*STDOUT );
+        $summary->print_day_summary( $app->_out_fh );
     }
     return;
 }
@@ -279,7 +291,7 @@ sub report_hours
 
     foreach my $summary ( @{$summaries} )
     {
-        $summary->print_hours( \*STDOUT );
+        $summary->print_hours( $app->_out_fh );
     }
     return;
 }
@@ -325,7 +337,30 @@ sub list_stack
     my ($app) = @_;
     return unless -f $app->_stackfile;
     my $stack = _stack( $app );
-    $stack->list( \*STDOUT );
+    $stack->list( $app->_out_fh );
+    return;
+}
+
+sub current_event
+{
+    my ($app) = @_;
+    my $fh = $app->_out_fh;
+
+    my $event = _get_last_full_event( $app );
+    if( $event->is_stop )
+    {
+        print {$fh} "Not in event.\n";
+        return;
+    }
+
+    # Use day summary object to get duration and to report.
+    my $summary = App::TimelogTxt::Day->new( $event->stamp );
+    $summary->start_task( $event );
+    $summary->update_dur( $event, time );
+
+    print {$fh} $event->to_string, "\nDuration: ";
+    $summary->print_duration( $fh );
+
     return;
 }
 
@@ -336,7 +371,7 @@ sub extract_day_tasks
 {
     my ( $app, @args ) = @_;
 
-    my ($stamp, $estamp, $pstamp, @filters) = process_extraction_args( @args );
+    my ($stamp, $estamp, $pstamp, @filters) = _process_extraction_args( @args );
     my ( $summary, $last, @summaries );
     my $prev_stamp = '';
 
@@ -373,7 +408,7 @@ sub extract_day_tasks
 
     # If the first summary is the day before we were supposed to report,
     #   drop it.
-    shift @summaries if $summaries[0]->date_stamp() eq $pstamp;
+    shift @summaries if @summaries && $summaries[0]->date_stamp() eq $pstamp;
 
     return [] unless $summary;
     my $end_time;
@@ -395,10 +430,10 @@ sub extract_day_tasks
 
     return if $summary->is_empty;
 
-    return filter_summaries( \@filters, \@summaries );
+    return _filter_summaries( \@filters, \@summaries );
 }
 
-sub filter_summaries
+sub _filter_summaries
 {
     my ( $filters, $summaries ) = @_;
 
@@ -413,7 +448,7 @@ sub filter_summaries
     ];
 }
 
-sub process_extraction_args
+sub _process_extraction_args
 {
     my ($day, @args) = @_;
 
@@ -475,12 +510,17 @@ sub _stack
     return App::TimelogTxt::Stack->new( $app->_stackfile );
 }
 
-sub _get_last_event
+sub _get_last_full_event
 {
     my ( $app ) = @_;
     my $event_line;
     _each_logline( $app, sub { $event_line = $_; } );
-    my $event = App::TimelogTxt::Event->new_from_line( $event_line );
+    return App::TimelogTxt::Event->new_from_line( $event_line );
+}
+
+sub _get_last_event
+{
+    my $event = _get_last_full_event( @_ );
 
     return $event->task;
 }
@@ -494,7 +534,7 @@ App::TimelogTxt - Commandline tracking of time for tasks and projects.
 
 =head1 VERSION
 
-This document describes App::TimelogTxt version 0.12
+This document describes App::TimelogTxt version 0.20
 
 =head1 SYNOPSIS
 
@@ -616,6 +656,13 @@ Implementation of the 'lstk' command.
 
 Print the current stack on STDOUT.
 
+=head2 current_event( $app )
+
+Implementation of the 'curr' command.
+
+Print the most recennt timelog event on STDOUT along with the duration since
+the start of the event. If not in an event, report that.
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 App::TimelogTxt requires no environment variables, but may use VISUAL or
