@@ -6,7 +6,7 @@ use strict;
 use App::TimelogTxt::Utils;
 use List::Util qw/sum/;
 
-our $VERSION = '0.12';
+our $VERSION = '0.20';
 
 sub new {
     my ($class, $stamp) = @_;
@@ -121,6 +121,14 @@ sub print_hours {
     return;
 }
 
+sub print_duration {
+    my ($self, $fh) = @_;
+    $fh ||= \*STDOUT;
+
+    print {$fh} _format_dur( $self->{dur} ), "\n";
+    return;
+}
+
 sub day_end
 {
     my ($self) = @_;
@@ -180,7 +188,7 @@ durations.
 
 =head1 VERSION
 
-This document describes App::TimelogTxt::Day version 0.12
+This document describes App::TimelogTxt::Day version 0.20
 
 =head1 SYNOPSIS
 
@@ -268,6 +276,20 @@ filehandle is supplied, print to C<STDOUT>.
 
 The output only displays the current datestamp and duration for the day.
 
+=head2 $d->print_duration( $fh )
+
+Print formatted duration information to the supplied filehandle C<$fh>. If no
+filehandle is supplied, print to C<STDOUT>.
+
+=head2 $d->has_tasks()
+
+Returns C<true> if the day contains one or more tasks.
+
+=head2 $d->day_filtered_by_project( $project )
+
+Make a copy of the current C<Day> object containing only the tasks associated
+with the supplied  C<$project>.
+
 =head2 $day->is_complete()
 
 Returns C<true> if the day is not currently in a task.
